@@ -67,12 +67,21 @@ private:
     std::vector<unsigned char> m_tilebuffer;
     std::vector<unsigned char> m_scratch;
 
+
+#ifdef USE_OPENJPH
+    // opj_cparameters_t m_compression_parameters;
+    std::unique_ptr<ojph::j2c_outfile> m_jph_image;
+    std::unique_ptr<ojph::codestream> m_jph_stream;
+    int output_depth;
+#endif
+
     void init(void)
     {
         m_image         = NULL;
         m_codec         = NULL;
         m_stream        = NULL;
         m_convert_alpha = true;
+
         ioproxy_clear();
     }
 
@@ -96,6 +105,10 @@ private:
             opj_stream_destroy(m_stream);
             m_stream = NULL;
         }
+#ifdef USE_OPENJPH
+        m_jph_stream.reset();
+        m_jph_image.reset();
+#endif
     }
 
     bool save_image();
@@ -139,6 +152,12 @@ private:
     }
 
     static void openjpeg_dummy_callback(const char* /*msg*/, void* /*data*/) {}
+
+#ifdef USE_OPENJPH
+    void create_jph_image();
+    template<typename T>
+    void write_jph_scanline(int y, int /*z*/, const void* data);
+#endif
 };
 
 
@@ -152,11 +171,16 @@ jpeg2000_output_imageio_create()
 }
 
 OIIO_EXPORT const char* jpeg2000_output_extensions[] = { "jp2", "j2k",
+#ifdef USE_OPENJPH
+                                                         "j2c", "jph",
+#endif
                                                          nullptr };
 
+
 OIIO_PLUGIN_EXPORTS_END
 
 
+
 bool
 Jpeg2000Output::open(const std::string& name, const ImageSpec& spec,
                      OpenMode mode)
@@ -186,6 +210,42 @@ Jpeg2000Output::open(const std::string& name, const ImageSpec& spec,
     if (m_spec.tile_width && m_spec.tile_height)
         m_tilebuffer.resize(m_spec.image_bytes());
 
+    const ParamValue* compressionparams = m_spec.find_attribute("compression",
+                                                                TypeString);
+#ifdef USE_OPENJPH
+
+    bool use_openjph = false;
+
+    // If a j2c file is specified, we default to j2c
+    // otherwise we check the compression parameter.
+
+    std::string compressionparms_str;
+    if (compressionparams) {
+        compressionparms_str = compressionparams->get_string();
+        if (compressionparms_str.compare(0, 5, "htj2k") == 0)
+            use_openjph = true;
+    }
+    std::string ext = Filesystem::extension(name);
+    if (ext == ".j2c")
+        // TODO - Need to check if j2c files can be created with openjpeg
+        use_openjph = true;
+
+    if (use_openjph) {
+        create_jph_image();
+        return true;
+    }
+#else
+    // If we are not using OpenJPH, we need to create a JPEG2000 image.
+    // This is the default behavior.
+    std::string compressionparms_str;
+    if (compressionparams) {
+        compressionparms_str = compressionparams->get_string();
+        if (compressionparms_str.compare(0, 5, "htj2k") == 0) {
+            errorfmt("OpenJPH not enabled, cannot create HTJ2K file");
+            return false;
+        }
+    }
+#endif
     m_image = create_jpeg2000_image();
     return true;
 }
@@ -252,10 +312,18 @@ Jpeg2000Output::write_scanline(int y, int z, TypeDesc format, const void* data,
                              m_spec.nchannels, m_spec.alpha_channel, 2.2f);
     }
 
-    if (m_spec.format == TypeDesc::UINT8)
-        write_scanline<uint8_t>(y, z, data);
-    else
-        write_scanline<uint16_t>(y, z, data);
+#ifdef USE_OPENJPH
+    if (m_jph_image) {
+        if (m_spec.format == TypeDesc::UINT8)
+            write_jph_scanline<uint8_t>(y, z, data);
+        else
+            write_jph_scanline<uint16_t>(y, z, data);
+    } else
+#endif  // USE_OPENJPH
+        if (m_spec.format == TypeDesc::UINT8)
+            write_scanline<uint8_t>(y, z, data);
+        else
+            write_scanline<uint16_t>(y, z, data);
 
     if (y == m_spec.height - 1)
         save_image();
@@ -293,6 +361,15 @@ Jpeg2000Output::close()
         std::vector<unsigned char>().swap(m_tilebuffer);
     }
 
+#ifdef USE_OPENJPH
+    if (m_jph_image) {
+        m_jph_stream->flush();
+        m_jph_stream->close();
+        destroy_stream();
+        return true;
+    }
+#endif
+
     if (m_image) {
         opj_image_destroy(m_image);
         m_image = NULL;
@@ -308,6 +385,15 @@ Jpeg2000Output::close()
 bool
 Jpeg2000Output::save_image()
 {
+#ifdef USE_OPENJPH
+    if (m_jph_stream) {
+        m_jph_stream->flush();
+        m_jph_stream->close();
+        destroy_stream();
+        return true;
+    }
+#endif
+
     m_codec = create_compressor();
     if (!m_codec)
         return false;
@@ -350,6 +436,7 @@ Jpeg2000Output::save_image()
 }
 
 
+
 opj_image_t*
 Jpeg2000Output::create_jpeg2000_image()
 {
@@ -405,6 +492,7 @@ Jpeg2000Output::create_jpeg2000_image()
 }
 
 
+
 inline void
 Jpeg2000Output::init_components(opj_image_cmptparm_t* components, int precision)
 {
@@ -424,6 +512,7 @@ Jpeg2000Output::init_components(opj_image_cmptparm_t* components, int precision)
 }
 
 
+
 opj_codec_t*
 Jpeg2000Output::create_compressor()
 {
@@ -512,6 +601,7 @@ Jpeg2000Output::setup_cinema_compression(OPJ_RSIZ_CAPABILITIES p_rsizCap)
 }
 
 
+
 void
 Jpeg2000Output::setup_compression_params()
 {
@@ -557,6 +647,8 @@ Jpeg2000Output::setup_compression_params()
         m_compression_parameters.mode = *(int*)compression_mode->data();
 }
 
+
+
 OPJ_PROG_ORDER
 Jpeg2000Output::get_progression_order(const std::string& progression_order)
 {
